from mikula.implementation.cli import create_parser
from mikula import __version__

parser = create_parser()
args = parser.parse_args()

if args.version:
    print(f"Mikula version {__version__}")
    exit(0)

if "function" in args:
    command = args.function
    delattr(args, "function")
    delattr(args, "version")
    kwargs = vars(args)
    command(**kwargs)



import os
import json
import boto3
from mikula.implementation.configure import read_credentials, AWS_REGIONS
from mikula.implementation.util import input_yes_no
import mimetypes as mime


def bucket_exists(s3_resource, bucket_name):
    existing_buckets = [bucket.name for bucket in s3_resource.buckets.all()]
    exists = bucket_name in existing_buckets
    return exists


def empty_bucket(s3_resource, bucket_name):
    bucket = s3_resource.Bucket(bucket_name)
    bucket.objects.all().delete()


def create_bucket(s3_resource, bucket_name, region):
    bucket = s3_resource.Bucket(bucket_name)
    configuration = {'LocationConstraint': region}
    bucket.create(CreateBucketConfiguration=configuration)


def configure_website_bucket(s3_resource, bucket_name):
    website_configuration = {'ErrorDocument': {'Key': 'error.html'},
                             'IndexDocument': {'Suffix': 'index.html'}}

    bucket_website = s3_resource.BucketWebsite(bucket_name)
    bucket_website.put(WebsiteConfiguration=website_configuration)

    cors_configuration = {
        'CORSRules': [{
            'AllowedHeaders': ['Authorization'],
            'AllowedMethods': ['GET'],
            'AllowedOrigins': ['*'],
            'ExposeHeaders': ['GET'],
            'MaxAgeSeconds': 3000
        }]
    }

    bucket_cors = s3_resource.BucketCors(bucket_name)
    bucket_cors.put(CORSConfiguration=cors_configuration)

    policy = {
        "Version": "2012-10-17",
        "Statement": [{
            "Sid": "PublicReadForGetBucketObjects",
            "Effect": "Allow",
            "Principal": "*",
            "Action": ["s3:GetObject"],
            "Resource": [f"arn:aws:s3:::{bucket_name}/*"]
        }
        ]
    }
    policy_string = json.dumps(policy)

    bucket_policy = s3_resource.BucketPolicy(bucket_name)
    bucket_policy.put(Policy=policy_string)


def upload_gallery(gallery, s3_resource, bucket_name):
    s3_bucket_object = s3_resource.Bucket(bucket_name)
    print(f'Uploading files to "{bucket_name}"')
    for subdir, dirs, files in os.walk(gallery):
        for file in files:
            full_path = os.path.join(subdir, file)
            mime_type = mime.guess_type(full_path)
            with open(full_path, 'rb') as data:
                key = full_path[len(gallery) + 1:]
                print(f'"{key}" - "{mime_type[0]}"')
                s3_bucket_object.put_object(Key=key,
                                            Body=data,
                                            ACL="public-read",
                                            ContentType=mime_type[0])


def deploy(gallery, bucket, region):
    credentials = read_credentials()
    s3 = boto3.resource('s3',
                        aws_access_key_id=credentials["aws_access_key_id"],
                        aws_secret_access_key=credentials["aws_secret_access_key"])

    if bucket_exists(s3, bucket_name=bucket):
        confirmed = input_yes_no(f"Bucket '{bucket}' already exists. All content in this bucket will be deleted. "
                                 f"Is this OK?")
        if not confirmed:
            return
        empty_bucket(s3, bucket_name=bucket)
    else:
        create_bucket(s3, bucket, region)

    configure_website_bucket(s3, bucket_name=bucket)
    upload_gallery(gallery, s3, bucket_name=bucket)
    url = f"http://{bucket}.s3-website-{region}.amazonaws.com"
    print("\nWebsite deployed successfully")
    print(f"It is available at {url}")



import yaml
import os

DEFAULTS = {
    "image_format": "png",
    "image_height": 600,
    "thumbnail_height": 200,
    "region": ""
}

AWS_REGIONS = ("us-east-2", "us-east-1", "us-west-1", "us-west-2",
               "ap-east-1", "ap-south-1", "ap-northeast-3", "ap-northeast-2",
               "ap-southeast-1", "ap-southeast-2", "ap-northeast-1",
               "ca-central-1", "cn-north-1", "cn-northwest-1",
               "eu-central-1", "eu-west-1", "eu-west-2", "eu-west-3", "eu-north-1",
               "sa-east-1", "me-south-1")


def save_credentials(filename, credentials):
    with open(filename, "w") as fid:
        fid.write("[default]\n")
        for key, value in credentials.items():
            fid.write(f"{key}={value}\n")


def configure(source, filename="configuration.yaml", reset=False):
    user_dir = os.path.expanduser("~")
    mikula_dir = os.path.join(user_dir, ".mikula")
    if not os.path.isdir(mikula_dir):
        os.mkdir(mikula_dir)
    credentials_fn = os.path.join(mikula_dir, "credentials")
    if not os.path.isfile(credentials_fn) or reset:
        credentials = dict()
        print("Enter your AWS credentials for S3 service")
        credentials["aws_access_key_id"] = input("AWS Access Key ID: ")
        credentials["aws_secret_access_key"] = input("AWS Secret Access Key: ")
        region = input("AWS region: ")
        if len(region) > 0:
            if region in AWS_REGIONS:
                credentials["region"] = region
            else:
                print(f"Unsupported region '{region}'. Please select one of the regions: {AWS_REGIONS}")
                return
        save_credentials(credentials_fn, credentials)
    fn = os.path.join(source, filename)
    with open(fn, "w") as fid:
        yaml.dump(DEFAULTS, fid)


def read_configuration(directory=".", filename="configuration.yaml"):
    fn = os.path.join(directory, filename)
    config = DEFAULTS
    if os.path.isfile(fn):
        with open(fn, "r") as fid:
            user_defined = yaml.load(fid, Loader=yaml.Loader)
            config.update(user_defined)
    return config


def read_credentials(filename="credentials"):
    def parse_credentials(s):
        key, value = s.split("=")
        return key.strip(), value.strip()

    user_dir = os.path.expanduser("~")
    credentials_fn = os.path.join(user_dir, ".mikula", filename)
    if not os.path.isfile(credentials_fn):
        return None

    credentials = dict()
    with open(credentials_fn, "r") as fid:
        for line in fid.readlines():
            if "=" in line:
                k, v = parse_credentials(line)
                credentials[k] = v
    return credentials



import argparse
import os
from mikula.implementation.configure import configure, read_configuration, DEFAULTS
from mikula.implementation.build import build
from mikula.implementation.serve import serve
from mikula.implementation.deploy import deploy


def create_parser():
    parser = argparse.ArgumentParser(description="Static Image Gallery Generator",
                                     usage="mikula [-h] {configure,build,serve,deploy} ...")
    parser.add_argument("--version",
                        help="Print version number",
                        action="store_true",
                        default=False)

    subparsers = parser.add_subparsers()

    serve_parser = subparsers.add_parser("configure")
    serve_parser.add_argument("--source",
                              help="Path to the gallery source files",
                              required=False,
                              default=os.getcwd())
    serve_parser.add_argument("--reset",
                              help="Reset AWS credentials",
                              action="store_true",
                              default=False)
    serve_parser.set_defaults(function=configure)

    build_parser = subparsers.add_parser("build")
    build_parser.add_argument("--source",
                              help="Gallery source directory containing images, metadata and settings",
                              default=os.getcwd(),
                              required=False)
    build_parser.add_argument("--output",
                              help="Output directory",
                              required=True)
    build_parser.add_argument("--theme",
                              help="theme",
                              default="default",
                              required=False)
    build_parser.set_defaults(function=build)

    serve_parser = subparsers.add_parser("serve")
    serve_parser.add_argument("--gallery",
                              help="path to the gallery",
                              default=os.getcwd(),
                              required=False)
    serve_parser.add_argument("--port",
                              help="Output directory",
                              type=int,
                              default=5000,
                              required=False)
    serve_parser.set_defaults(function=serve)

    deploy_parser = subparsers.add_parser("deploy")
    deploy_parser.add_argument("--gallery",
                               help="path to the gallery",
                               default=os.getcwd(),
                               required=False)
    deploy_parser.add_argument("--bucket",
                               help="Name of AWS S3 bucket",
                               required=True)
    deploy_parser.add_argument("--region",
                               help="Name of AWS S3 region",
                               default=read_configuration().get("region", DEFAULTS["region"]),
                               required=False)
    deploy_parser.set_defaults(function=deploy)

    return parser




import os
import uuid
import glob
from collections import OrderedDict
from mikula.implementation.images import is_image
from mikula.implementation.md import render_markdown, DEFAULT_ERROR, DEFAULT_PAGE_META
from mikula.implementation import settings
from mikula.implementation.util import walk

PAGES_DIR = settings.pages_source
IGNORED = settings.ignored


def parse_pages(source_directory):
    parsed = OrderedDict()
    pattern = os.path.join(source_directory, PAGES_DIR, "*.md")
    for fn in glob.glob(pattern):
        meta, content = render_markdown(fn, DEFAULT_PAGE_META)
        basename, _ = os.path.splitext(os.path.basename(fn))
        if "title" not in meta:
            meta["title"] = basename
        parsed[basename] = (meta, content)
    return parsed


def discover(directory, image_format):
    nodes = walk(directory, exclude=IGNORED, topdown=False)
    parsed = OrderedDict()
    excluded = dict()
    for source_dir, subdirs, files in nodes:
        images = OrderedDict()
        index_content = ""
        index_meta = dict()
        path = os.path.relpath(directory, source_dir)
        for file in files:
            fn = os.path.join(source_dir, file)
            if "index.md" in file.lower():
                index_meta, index_content = render_markdown(fn, DEFAULT_PAGE_META)
                continue
            if is_image(fn):
                image_id = str(uuid.uuid4())
                image_file = f"{image_id}.{image_format.lower()}"
                basename, _ = os.path.splitext(file)
                markdown_fn = os.path.join(source_dir, f"{basename}.md")
                if os.path.isfile(markdown_fn):
                    meta, html = render_markdown(markdown_fn)
                    meta["title"] = meta.get("title", basename)
                else:
                    meta = {"title": basename}
                    html = ""
                meta["basename"] = basename
                images[file] = (image_file, meta, html)

        relative = os.path.relpath(source_dir, directory)

        if "thumbnail" in index_meta.keys():
            fn = index_meta["thumbnail"]
            if fn in images.keys():
                file_id, *rest = images[fn]
                index_meta["thumbnail"] = file_id
                should_remove = index_meta.get("exclude_thumbnail", False)
                if should_remove:
                    excluded[relative] = (fn, images[fn][0])
                    del images[fn]
        parsed[relative] = (path, subdirs, images, index_meta, index_content)

    top_dir, _, files = nodes[-1]
    if "error.md" in files:
        fn = os.path.join(top_dir, "error.md")
        error_meta, error_content = render_markdown(fn)
    else:
        error_meta = {"title": "Server Error", "page_title": "Server Error"}
        error_content = DEFAULT_ERROR

    return parsed, excluded, (error_meta, error_content)



import markdown
import yaml
import re
import copy

DEFAULT_ERROR = "<p class='error-message'>Something bad happened. Please visit the site later.</p>"
DEFAULT_PAGE_META = {"place_before": False}


def extract_meta(document, defaults):
    def remove_first_line(text):
        split = text.splitlines()
        return "\n".join(split[1:])

    pattern = r"(?<=---\n)(?P<meta>.+(?=---))(?P<rest>.+)"
    compiled = re.compile(pattern, re.IGNORECASE | re.DOTALL)
    matched = compiled.search(document)
    if defaults is None:
        metadata = dict()
    else:
        metadata = copy.deepcopy(defaults)
    if matched is not None:
        meta = matched.group("meta")
        from_yaml = yaml.load(meta, yaml.Loader)
        metadata.update(from_yaml)
        rest = matched.group("rest")
        return metadata, remove_first_line(rest)
    else:
        return metadata, document


def render_markdown(md_file, meta_defaults=None):
    with open(md_file, "r") as fid:
        content = fid.read()
    meta, document = extract_meta(content, meta_defaults)
    html = markdown.markdown(document)
    return meta, html



import os
import shutil
from distutils.dir_util import copy_tree
from mikula.implementation import settings


def input_yes_no(question):
    reply = None
    while reply not in ("y", "n"):
        reply = str(input(question+' (y/n): ')).lower().strip()
    return True if reply == "y" else False


def extension(file):
    _, ext = os.path.splitext(file)
    ext = ext.upper()
    return ext[1:]


def create(directory):
    if os.path.isdir(directory):
        shutil.rmtree(directory)
    if not os.path.isdir(directory):
        os.mkdir(directory)


def create_directories(parsed, output_directory):
    create(output_directory)

    gallery_dir = os.path.join(output_directory, settings.gallery_dir)
    create(gallery_dir)

    images_dir = os.path.join(gallery_dir, settings.images_dir)
    create(images_dir)

    thumbnails_dir = os.path.join(images_dir, settings.thumbnails_dir)
    create(thumbnails_dir)

    for directory in reversed(parsed.keys()):
        absolute = os.path.join(output_directory, directory)
        if not os.path.isdir(absolute):
            os.mkdir(absolute)


def copy_assets(theme, output_directory):
    src = os.path.join(theme, "assets")
    dst = os.path.join(output_directory, settings.assets_dir)
    shutil.copytree(src, dst)


def copy_user_assets(source, output):
    src = os.path.join(os.path.abspath(source), settings.assets_source)
    dst = os.path.join(os.path.abspath(output), settings.user_assets_dir)
    if os.path.isdir(src):
        copy_tree(src, dst)


def walk(path, exclude=tuple(), topdown=False):
    nodes = list()
    for root, dirs, files in os.walk(path, topdown=True):
        dirs[:] = [d for d in dirs if d not in exclude]
        nodes.append((root, dirs, files))
    if not topdown:
        nodes.reverse()
    return nodes


def get_theme_directory(theme):
    d = os.path.dirname(__file__)
    return os.path.abspath(os.path.join(d, "..", "themes", theme))



import http.server
import socketserver


def serve(gallery, port):

    class Handler(http.server.SimpleHTTPRequestHandler):
        def __init__(self, *args, **kwargs):
            super().__init__(*args, directory=gallery, **kwargs)

    with socketserver.TCPServer(("", port), Handler) as httpd:
        print(f"Serving on 'http://localhost:{port}'")
        print("Ctrl + C to exit")
        try:
            httpd.serve_forever()
        except KeyboardInterrupt:
            print("\ndone")



gallery_dir = "_gallery_"
images_dir = "images"
thumbnails_dir = "thumbnails"
assets_dir = "_assets_"
user_assets_dir = "_user-assets_"

pages_source = "__pages__"
assets_source = "__assets__"
ignored = (pages_source, assets_source, ".git")



import os
from PIL import Image, ExifTags
from mikula.implementation.exif import nominal_shutter_speed, nominal_f_number, nominal_aperture
from mikula.implementation.settings import gallery_dir, images_dir, thumbnails_dir

EXIF_ORIENTATION = 0x0112
ROTATION = {3: 180, 6: 270, 8: 90}
TAG_CODE = {key: value for key, value in zip(ExifTags.TAGS.values(), ExifTags.TAGS.keys())}
GALLERY = gallery_dir
IMAGES = images_dir
THUMBNAILS = thumbnails_dir

def is_image(filename):
    try:
        Image.open(filename)
    except IOError:
        return False
    return True


def convert_image(original, converted, directory, images_dst, thumbnails_dst,
                  source_directory, height, image_format, thumbnail_height):
    file_path = os.path.join(source_directory, directory, original)
    img = Image.open(file_path)
    exif = img._getexif()
    if exif is not None:
        if EXIF_ORIENTATION in exif.keys():
            code = exif[EXIF_ORIENTATION]
            angle = ROTATION.get(code, None)
            if angle is not None:
                img = img.rotate(angle, expand=True)
    aspect = img.height / img.width
    width = int(height / aspect)
    img = img.resize((width, height), Image.ANTIALIAS)

    image_dst = os.path.join(images_dst, converted)
    img.save(image_dst, format=image_format)

    thumbnail_width = int(thumbnail_height / aspect)
    img.thumbnail((thumbnail_width, thumbnail_height))
    thumbnail_dst = os.path.join(thumbnails_dst, converted)
    img.save(thumbnail_dst, format=image_format)
    img.close()
    return exif


def extract_exif_meta(meta, exif, album_meta):
    def get_exif_values(tags):
        output = dict()
        for tag in tags:
            if tag in TAG_CODE.keys():
                if tag == "ShutterSpeedValue":
                    value = exif.get(TAG_CODE[tag], None)
                    if value is not None:
                        output[tag] = nominal_shutter_speed(*value)
                    continue
                if tag == "FNumber":
                    value = exif.get(TAG_CODE[tag], None)
                    if value is not None:
                        output[tag] = nominal_f_number(*value)
                    continue
                if tag == "ApertureValue":
                    value = exif.get(TAG_CODE[tag], None)
                    if value is not None:
                        output[tag] = nominal_aperture(*value)
                    continue
                output[tag] = exif.get(TAG_CODE[tag], None)
        return output

    if exif is None:
        if "exif" in meta:
            del meta["exif"]
        return meta

    if "exif" in meta:
        exif_tags = meta["exif"]
    else:
        exif_tags = album_meta.get("exif", tuple())
    meta["exif"] = get_exif_values(exif_tags)
    return meta


def process_images(source_directory, parsed, excluded, output, config):
    image_format = config["image_format"]
    height = config["image_height"]
    thumbnail_height = config["thumbnail_height"]
    images_dst = os.path.join(output, GALLERY, IMAGES)
    thumbnails_dst = os.path.join(images_dst, THUMBNAILS)
    for directory, content in parsed.items():
        relative, subdirs, images, index_meta, index_content = content
        if directory in excluded.keys():
            excluded_original, excluded_converted = excluded[directory]
            convert_image(excluded_original, excluded_converted, directory, images_dst, thumbnails_dst,
                          source_directory, height,
                          image_format, thumbnail_height)
        for original, record in images.items():
            converted, meta, _ = record
            exif = convert_image(original, converted, directory, images_dst, thumbnails_dst, source_directory, height,
                                 image_format, thumbnail_height)
            meta = extract_exif_meta(meta, exif, index_meta)



import os
from jinja2 import Environment, FileSystemLoader, select_autoescape, Template
from mikula.implementation import settings

GALLERY = settings.gallery_dir
IMAGES = settings.images_dir
THUMBNAILS = settings.thumbnails_dir


def parse_subdirectories(album, keys, index):
    output = list()
    current = keys[index]
    relative, subdirectories, _, album_meta, album_md = album[current]
    for directory in subdirectories:
        key = os.path.normpath(os.path.join(current, directory))
        _, _, _, meta, _ = album[key]
        title = meta.get("title", directory)
        url = os.path.join(directory, "index.html")
        thumbnail_filename = meta.get("thumbnail", None)
        if thumbnail_filename is not None:
            thumbnail_url = os.path.join(relative, GALLERY, IMAGES, THUMBNAILS, thumbnail_filename)
        else:
            thumbnail_url = None
        output.append((title, url, thumbnail_url))
    return relative, output, album_meta, album_md


def parse_images(album, keys, index):
    output = list()
    relative, _, image_files, *rest = album[keys[index]]

    for original, (image_file, image_meta, _) in image_files.items():
        image_name = image_meta["title"]
        image_url = f"{image_meta['basename']}.html"
        thumbnail_url = os.path.join(relative, GALLERY, IMAGES, THUMBNAILS, image_file)
        output.append((image_name, image_url, os.path.normpath(thumbnail_url)))
    return output


def parent_album(index, length):
    if index < length - 1:
        return "../index.html"
    return None


def render_album_page(album, keys, index, template, page_list):
    gallery_root, child_albums, meta, content = parse_subdirectories(album, keys, index)
    thumbnails = parse_images(album, keys, index)
    user_content = Template(content)
    if "page_title" not in meta.keys():
        meta["page_title"] = meta["title"]
    html = template.render(page_list_=page_list,
                           root_=gallery_root,
                           user_content_=user_content,
                           back_=parent_album(index, len(keys)),
                           albums_=child_albums,
                           thumbnails_=thumbnails,
                           **meta)
    return html


def get_image_page(image_files, image_keys, index):
    if index < 0 or index >= len(image_keys):
        return None
    original = image_keys[index]
    _, meta, _ = image_files[original]
    return f"{meta['basename']}.html"


def render_image_page(gallery_root, image_files, image_keys, image_index,
                      image_template, relative_path, page_list):
    image_file, meta, content = image_files[image_keys[image_index]]
    user_content = Template(content)
    if "page_title" not in meta.keys():
        meta["page_title"] = meta["title"]
    html = image_template.render(page_list_=page_list,
                                 root_=gallery_root,
                                 user_content_=user_content,
                                 image_=os.path.join(relative_path, image_file),
                                 previous_=get_image_page(image_files, image_keys, image_index - 1),
                                 next_=get_image_page(image_files, image_keys, image_index + 1),
                                 **meta)
    return html, f"{meta['basename']}.html"


def create_page(page, page_list, destination_directory, filename, template):
    meta, content = page
    user_content = Template(content)
    html = template.render(user_content_=user_content,
                           page_list_=page_list,
                           **meta)
    fn = os.path.join(destination_directory, filename)
    with open(fn, "w") as fid:
        fid.write(html)


def render_pages(pages, destination_directory, template):
    page_list = list()
    render_list = list()
    for basename, page in pages.items():
        fn = f"{basename}.html"
        meta, _ = page
        home_page = meta.get("render_gallery_here", False)
        if home_page:
            fn = "index.html"
        else:
            render_list.append((page, fn))
        page_list.append((meta["title"], fn))

    for content, fn in render_list:
        create_page(content, page_list, destination_directory, fn, template)

    return page_list


def render(album, error_page, pages, output_directory, theme):
    env = Environment(
        loader=FileSystemLoader(theme),
        autoescape=select_autoescape(['html', 'xml'])
    )
    album_template = env.get_template("album.html")
    image_template = env.get_template("image.html")
    error_template = env.get_template("error.html")

    page_list = list()
    if len(pages) > 0:
        pages_template = env.get_template("pages.html")
        page_list = render_pages(pages, output_directory, pages_template)

    create_page(error_page, page_list, output_directory, "error.html", error_template)

    keys = tuple(album.keys())
    for index in range(len(keys)):
        album_page = render_album_page(album, keys, index, album_template, page_list)
        dst_directory = os.path.join(output_directory, keys[index])
        album_filename = os.path.join(dst_directory, "index.html")
        with open(album_filename, 'w') as fid:
            fid.write(album_page)

        relative, _, image_files, _, _ = album[keys[index]]
        image_keys = tuple(image_files.keys())
        relative_path = os.path.join(relative, GALLERY, IMAGES)
        for k in range(len(image_keys)):
            image_page, filename = render_image_page(gallery_root=relative,
                                                     image_files=image_files,
                                                     image_keys=image_keys,
                                                     image_index=k,
                                                     image_template=image_template,
                                                     relative_path=relative_path,
                                                     page_list=page_list)
            fn = os.path.join(dst_directory, filename)
            with open(fn, "w") as fid:
                fid.write(image_page)



from mikula.implementation.configure import read_configuration
from mikula.implementation.images import process_images
from mikula.implementation.discovery import discover, parse_pages
from mikula.implementation.util import create_directories, copy_user_assets, copy_assets, get_theme_directory
from mikula.implementation.rendering import render


def build(source, output, theme):
    theme_directory = get_theme_directory(theme)
    config = read_configuration(directory=source, filename="configuration.yaml")
    album, excluded, error_page = discover(source, config["image_format"])
    pages = parse_pages(source_directory=source)
    create_directories(album, output)
    copy_assets(theme_directory, output)
    copy_user_assets(source, output)
    process_images(source, album, excluded, output, config)
    render(album, error_page, pages, output, theme_directory)
    print(f'Gallery built in "{output}"')



import setuptools
import os
import pathlib

with open("README.md", "r") as fh:
    long_description = fh.read()


PATH = os.path.dirname(__file__)


def include_data(themes_directory, *extra):
    content = list()
    path = pathlib.Path(themes_directory)
    for current, _, _ in os.walk(themes_directory):
        relative = os.path.relpath(current, path.parent)
        content.append(os.path.join(relative, "*"))
    content.extend(extra)
    return content


def get_version():
    with open(os.path.join(PATH, "mikula", "VERSION")) as version_file:
        version = version_file.read().strip()
    return version


print(include_data(os.path.join("mikula", "themes"),
                   "VERSION",
                    "LICENSE"))

setuptools.setup(
    name="mikula",
    version=get_version(),
    author="Roman Kosobrodov",
    author_email="mikula@kosobrodov.net",
    description="Static web gallery generator",
    license="MIT",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/RomanKosobrodov/mikula",
    packages=setuptools.find_packages(exclude=["*.tests", "*.tests.*", "tests.*", "tests"]),
    package_data={
        'mikula': include_data(os.path.join("mikula", "themes"), "VERSION")
    },
    scripts=['bin/mikula'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent"
    ],
    python_requires='>=3.6',
    install_requires=[
        "boto3==1.10.26",
        "Jinja2==2.10.3",
        "Markdown==3.1.1",
        "Pillow==6.2.1",
        "PyYAML==5.1.2"
    ]
)
